searchData={"items":[{"type":"module","title":"Base85","doc":"Implements some 85-character encodings.\n\nWhile Base64 is well known and quite functional, it is not the most\nefficient encoding for turning binary data into a stream of ASCII-friendly\ntext. This module implements some Base85 encodings. As the name suggests,\nit encodes data using a numbering system with a radix of 85. This number is\nchosen because it approximates the maximum number of characters in the\n\"safe\" range that can be effectively used.\n\nWhile it is possible to squeeze out a few more, it doesn't actually save\nany characters. So, from an efficiency standpoint, Base85 is about as good\nas it gets. And the small number of characters you have left over, you can\ntune the generated output to avoid characters that are \"dangerous\" in\ncertain transports.\n\nThis module holds references to the primary entrypoints for using this\nlibrary.","ref":"Base85.html"},{"type":"function","title":"Base85.decode/2","doc":"","ref":"Base85.html#decode/2"},{"type":"function","title":"Base85.decode!/2","doc":"","ref":"Base85.html#decode!/2"},{"type":"function","title":"Base85.encode/2","doc":"","ref":"Base85.html#encode/2"},{"type":"function","title":"Base85.encode!/2","doc":"","ref":"Base85.html#encode!/2"},{"type":"module","title":"Base85.Charsets","doc":"Implements various character sets used for Base85 encoding.","ref":"Base85.Charsets.html"},{"type":"type","title":"Base85.Charsets.charset/0","doc":"available character sets","ref":"Base85.Charsets.html#t:charset/0"},{"type":"function","title":"Base85.Charsets.charsets/0","doc":"Returns a map of character sets.","ref":"Base85.Charsets.html#charsets/0"},{"type":"module","title":"Base85.Decode","doc":"Implements decoding functionality for Base85 encoding.","ref":"Base85.Decode.html"},{"type":"type","title":"Base85.Decode.charset/0","doc":"available character sets","ref":"Base85.Decode.html#t:charset/0"},{"type":"function","title":"Base85.Decode.decode/2","doc":"Decodes binary data from a Base85-encoded string.\n\nThis version returns an `:ok`-tuple or `:error`-tuple.","ref":"Base85.Decode.html#decode/2"},{"type":"function","title":"Examples - Base85.Decode.decode/2","doc":"iex> Base85.Decode.decode(\"N.Xx21Kf++HD3`AI>AZp$Aer7\", charset: :safe85, padding: :pkcs7)\n    {:ok, \"some binary data\"}\n\n    iex> Base85.Decode.decode(\"f!$Kwf!$Kwf!$Kw\", charset: :zeromq, padding: :none)\n    {:ok, \"123412341234\"}\n\n    iex> Base85.Decode.decode(\"123\", charset: :safe85, padding: :none)\n    {:error, :invalid_encoded_length}","ref":"Base85.Decode.html#decode/2-examples"},{"type":"function","title":"Options - Base85.Decode.decode/2","doc":"* `binary` - the binary data to decode, must be a multiple of 5-characters\n    long;\n\n  * `:charset` - an atom indicating the character set to use for decoding;\n\n  * `:padding` - an atom indicating which padding technique to use;\n\n  Padding methods and encodings may use additional options.","ref":"Base85.Decode.html#decode/2-options"},{"type":"function","title":"Base85.Decode.decode!/2","doc":"Decodes binary data from a Base85-encoded string.\n\nThis version returns the value or raises an error.","ref":"Base85.Decode.html#decode!/2"},{"type":"function","title":"Examples - Base85.Decode.decode!/2","doc":"iex> Base85.Decode.decode!(\"N.Xx21Kf++HD3`AI>AZp$Aer7\", charset: :safe85, padding: :pkcs7)\n    \"some binary data\"\n\n    iex> Base85.Decode.decode!(\"f!$Kwf!$Kwf!$Kw\", charset: :zeromq, padding: :none)\n    \"123412341234\"\n\n    iex> Base85.Decode.decode!(\"123\", charset: :safe85, padding: :none)\n    ** (Base85.InvalidEncodedLength) encoded data had invalid encoded length, expected multiple of 5 characters","ref":"Base85.Decode.html#decode!/2-examples"},{"type":"function","title":"Options - Base85.Decode.decode!/2","doc":"* `binary` - the binary data to decode, must be a multiple of 5-characters\n    long;\n\n  * `:charset` - an atom indicating the character set to use for decoding;\n\n  * `:padding` - an atom indicating which padding technique to use;\n\n  Padding methods and encodings may use additional options.","ref":"Base85.Decode.html#decode!/2-options"},{"type":"type","title":"Base85.Decode.decoding_error/0","doc":"decoding errors","ref":"Base85.Decode.html#t:decoding_error/0"},{"type":"type","title":"Base85.Decode.decoding_opts/0","doc":"options for decoding","ref":"Base85.Decode.html#t:decoding_opts/0"},{"type":"type","title":"Base85.Decode.padding/0","doc":"available padding techniques","ref":"Base85.Decode.html#t:padding/0"},{"type":"module","title":"Base85.Encode","doc":"Implements encoding functionality for Base85 encoding.","ref":"Base85.Encode.html"},{"type":"type","title":"Base85.Encode.charset/0","doc":"available character sets","ref":"Base85.Encode.html#t:charset/0"},{"type":"function","title":"Base85.Encode.encode/2","doc":"Encodes binary data into a Base85-encoded string.\n\nThis version returns an `:ok`-tuple or `:error`-tuple.","ref":"Base85.Encode.html#encode/2"},{"type":"function","title":"Examples - Base85.Encode.encode/2","doc":"iex> Base85.Encode.encode(\"some binary data\", charset: :safe85, padding: :pkcs7)\n    {:ok, \"N.Xx21Kf++HD3`AI>AZp$Aer7\"}\n\n    iex> Base85.Encode.encode(\"123412341234\", charset: :zeromq, padding: :none)\n    {:ok, \"f!$Kwf!$Kwf!$Kw\"}\n\n    iex> Base85.Encode.encode(\"123\", charset: :safe85, padding: :none)\n    {:error, :invalid_unencoded_length}","ref":"Base85.Encode.html#encode/2-examples"},{"type":"function","title":"Options - Base85.Encode.encode/2","doc":"* `binary` - the binary data to encode, must be a multiple of 32-bits long\n    if no padding is used;\n\n  * `:charset` - an atom indicating the character set to use for encoding;\n\n  * `:padding` - an atom indicating which padding technique to use;\n\n  Padding methods and encodings may use additional options.","ref":"Base85.Encode.html#encode/2-options"},{"type":"function","title":"Base85.Encode.encode!/2","doc":"Encodes binary data into a Base85-encoded string.\n\nThis version returns the value or raises an error.","ref":"Base85.Encode.html#encode!/2"},{"type":"function","title":"Examples - Base85.Encode.encode!/2","doc":"iex> Base85.Encode.encode!(\"some binary data\", charset: :safe85, padding: :pkcs7)\n    \"N.Xx21Kf++HD3`AI>AZp$Aer7\"\n\n    iex> Base85.Encode.encode!(\"123412341234\", charset: :zeromq, padding: :none)\n    \"f!$Kwf!$Kwf!$Kw\"\n\n    iex> Base85.Encode.encode!(\"123\", charset: :safe85, padding: :none)\n    ** (Base85.InvalidUnencodedLength) raw data had invalid length for padding method none, expected multiple of 4 bytes","ref":"Base85.Encode.html#encode!/2-examples"},{"type":"function","title":"Options - Base85.Encode.encode!/2","doc":"* `binary` - the binary data to encode, must be a multiple of 32-bits long\n    if no padding is used;\n\n  * `:charset` - an atom indicating the character set to use for encoding;\n\n  * `:padding` - an atom indicating which padding technique to use;\n\n  Padding methods and encodings may use additional options.","ref":"Base85.Encode.html#encode!/2-options"},{"type":"type","title":"Base85.Encode.encoding_error/0","doc":"encoding errors","ref":"Base85.Encode.html#t:encoding_error/0"},{"type":"type","title":"Base85.Encode.encoding_opts/0","doc":"options for encoding","ref":"Base85.Encode.html#t:encoding_opts/0"},{"type":"type","title":"Base85.Encode.padding/0","doc":"available padding techniques","ref":"Base85.Encode.html#t:padding/0"},{"type":"module","title":"Base85.Padding","doc":"Implements various padding schemes for Base85 encodings.\n\nThis module has no externally useful functions.","ref":"Base85.Padding.html"},{"type":"function","title":"Base85.Padding.get_unpad_fun/1","doc":"Used to get an unpadding function for a given padding type.","ref":"Base85.Padding.html#get_unpad_fun/1"},{"type":"type","title":"Base85.Padding.padding/0","doc":"padding methods","ref":"Base85.Padding.html#t:padding/0"},{"type":"exception","title":"Base85.InternalError","doc":"Raised at runtime when an internal error is encountered.","ref":"Base85.InternalError.html"},{"type":"exception","title":"Base85.InvalidCharacterForCharacterSet","doc":"Raised at runtime when decoding finds an invalid coding for the specified\ncharacter set.","ref":"Base85.InvalidCharacterForCharacterSet.html"},{"type":"exception","title":"Base85.InvalidEncodedLength","doc":"Raised at runtime when presented with encoded data with an invalid length.","ref":"Base85.InvalidEncodedLength.html"},{"type":"function","title":"Base85.InvalidEncodedLength.message/1","doc":"","ref":"Base85.InvalidEncodedLength.html#message/1"},{"type":"exception","title":"Base85.InvalidPaddingData","doc":"Raised at runtime when presented with data with corrupted padding data.","ref":"Base85.InvalidPaddingData.html"},{"type":"exception","title":"Base85.InvalidUnencodedLength","doc":"Raised at runtime when presented with unencoded data with an invalid\nlength.","ref":"Base85.InvalidUnencodedLength.html"},{"type":"exception","title":"Base85.UnrecognizedCharacterSet","doc":"Raised at runtime when an unknown character set is specified.","ref":"Base85.UnrecognizedCharacterSet.html"},{"type":"exception","title":"Base85.UnrecognizedPadding","doc":"Raised at runtime when an unknown padding method is specified.","ref":"Base85.UnrecognizedPadding.html"},{"type":"extras","title":"Overview","doc":"# Base85\n\nImplements some base-85 character encodings.\n\nSupported character sets include:\n- ZeroMQ's Z85\n- Safe85 (character set only, not padding)\n- PostgreSQL-safe\n\nSupported padding methods include:\n- None\n- PKCS7-style\n\nNote that this currently does *not* implement padding used for full support of\nSafe85 or Safe85L.\n\nThe PostgreSQL-safe character set eliminates characters used in SQL comments,\nstatement termination, quoting, and placeholders.\n\nUnsupported character sets include:\n- Adobe ASCII85\n- btoa\n- ZModem Pack-7","ref":"readme.html"},{"type":"extras","title":"Installation - Overview","doc":"This package is [available in Hex](https://hex.pm/packages/base85). The package\ncan be installed by adding `base85` to your list of dependencies in `mix.exs`:\n\n```elixir\ndef deps do\n  [\n    {:base85, \"~> 0.2.0\"}\n  ]\nend\n```\n\nDocumentation is generated with [ExDoc](https://github.com/elixir-lang/ex_doc)\nand published on [HexDocs](https://hexdocs.pm). The docs can\nbe found at [https://hexdocs.pm/base85](https://hexdocs.pm/base85).","ref":"readme.html#installation"},{"type":"extras","title":"Supporters - Overview","doc":"A special thanks to everyone who has generously donated their time, effort, or\nfunds to this project.\n\n<!-- readme: jvantuyl,collaborators,contributors,sponsors,bots/- -start -->\n<!-- readme: jvantuyl,collaborators,contributors,sponsors,bots/- -end -->","ref":"readme.html#supporters"},{"type":"extras","title":"License","doc":"# MIT License\n\nCopyright (c) 2021 Jayson Vantuyl\n\nPermission is hereby granted, free of charge, to any person obtaining\na copy of this software and associated documentation files (the\n\"Software\"), to deal in the Software without restriction, including\nwithout limitation the rights to use, copy, modify, merge, publish,\ndistribute, sublicense, and/or sell copies of the Software, and to\npermit persons to whom the Software is furnished to do so, subject to\nthe following conditions:\n\nThe above copyright notice and this permission notice shall be\nincluded in all copies or substantial portions of the Software.\n\nTHE SOFTWARE IS PROVIDED \"AS IS\", WITHOUT WARRANTY OF ANY KIND,\nEXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF\nMERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND\nNONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT HOLDERS BE\nLIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION\nOF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION\nWITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.","ref":"license.html"}],"proglang":"elixir","content_type":"text/markdown","producer":{"name":"ex_doc","version":"0.36.1"}}